@@ -3,18 +3,14 @@ package Log::Dispatch::Null;
 use strict;
 use warnings;
 
-our $VERSION = '2.51';
-
-use Log::Dispatch::Output;
+our $VERSION = '2.71';
 
 use base qw( Log::Dispatch::Output );
 
 sub new {
-    my $proto = shift;
-    my $class = ref $proto || $proto;
+    my $class = shift;
 
     my $self = bless {}, $class;
-
     $self->_basic_init(@_);
 
     return $self;
@@ -30,13 +26,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Null - Object that accepts messages and does nothing
 
 =head1 VERSION
 
-version 2.51
+version 2.71
 
 =head1 SYNOPSIS
 
@@ -49,21 +47,32 @@ version 2.51
 
 =head1 DESCRIPTION
 
-This class provides a null logging object. Messages can be sent to the
-object but it does nothing with them.
+This class provides a null logging object. Messages can be sent to the object
+but it does nothing with them.
 
 =for Pod::Coverage new log_message
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
+
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dave Rolsky.
+This software is Copyright (c) 2023 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
